/*---------------------------------------------------------------------\
|                          ____ _   __ __ ___                          |
|                         |__  / \ / / . \ . \                         |
|                           / / \ V /|  _/  _/                         |
|                          / /__ | | | | | |                           |
|                         /_____||_| |_| |_|                           |
|                                                                      |
\---------------------------------------------------------------------*/
/** \file zypp/media/proxyinfo/ProxyInfos.h
 *
*/
#ifndef ZYPP_MEDIA_PROXYINFO_PROXYINFOS_H
#define ZYPP_MEDIA_PROXYINFO_PROXYINFOS_H

#include <string>
#include <list>

#include <zypp/media/proxyinfo/ProxyInfoSysconfig.h>
#ifdef WITH_LIBPROXY_SUPPORT
#include <zypp/media/proxyinfo/ProxyInfoLibproxy.h>
#endif

#endif // ZYPP_MEDIA_PROXYINFO_PROXYINFOS_H
